Global mean temperature is based on measurements made at weather stations over land and by ships and buoys over the ocean. Temperatures are typically expressed as anomalies which are temperature differences from the average for a standard period. Here, 1850-1900 is used for the global mean. Instrumental temperature records are some of the longest climate records available, with some series extending back to the 17th century.